@@ -17,7 +17,7 @@
  */
 
 /*
- * Copyright (C) 2020-2023 Oracle and/or its affiliates.
+ * Copyright (C) 2020-2024 Oracle and/or its affiliates.
  *
  * This file is part of VirtualBox base platform packages, as
  * available from https://www.virtualbox.org.
@@ -1800,7 +1800,7 @@ static DECLCALLBACK(int) rtFtpServerDataConnListThread(RTTHREAD ThreadSelf, void
      * If no argument is given, the implementation must use the last directory set. */
     char *pszPath = RTStrDup(  pDataConn->cArgs == 1
                              ? pDataConn->papszArgs[0] : pDataConn->pClient->State.pszCWD); /** @todo Needs locking. */
-    AssertPtrReturn(pszPath, VERR_NO_MEMORY);
+    AssertPtrReturnStmt(pszPath, rtFtpServerDataConnDirCollFree(pColl), VERR_NO_MEMORY);
     /* The paths already have been validated in the actual command handlers. */
 
     void *pvHandle = NULL; /* Shut up MSVC. */
